@@ -11,6 +11,10 @@ pad = lambda s: s + (BLOCK_SIZE - len(s) % BLOCK_SIZE) * chr(BLOCK_SIZE - len(s)
 unpad = lambda s: s[:-ord(s[len(s)-1:])]
 
 
+def generate_iv():
+    return Random.get_random_bytes(BLOCK_SIZE)
+
+
 class Crypt(object):
     def __init__(self, password):
         self.password = password
@@ -20,10 +24,10 @@ class Crypt(object):
 
     def encrypt(self, data, salt):
         aes = AES.new(self._derive_key(salt), AES.MODE_CBC,
-                      Random.get_random_bytes(BLOCK_SIZE))
-        return aes.IV.encode('hex'), aes.encrypt(pad(data)).encode('hex')
+                      generate_iv())
+        return aes.IV.encode('hex'), aes.encrypt(pad(data.decode('hex'))).encode('hex')
 
     def decrypt(self, encrypted, salt, iv):
         encrypted, salt, iv = str(encrypted), str(salt), str(iv)
         aes = AES.new(self._derive_key(salt), AES.MODE_CBC, iv.decode('hex'))
-        return unpad(aes.decrypt(encrypted.decode('hex')))
+        return unpad(aes.decrypt(encrypted.decode('hex'))).encode('hex')
